@@ -40,7 +40,7 @@ from calculate.lib.utils.files import (getModeFile, removeDir,
                                        listDirectory,process,find,STDOUT,
                                        sambaPasswordCheck,checkUtils)
 from calculate.lib.utils.common import (getpathenv, appendProgramToEnvFile,
-                                        removeProgramToEnvFile)
+                                        removeProgramToEnvFile, cmpVersion)
 from calculate.desktop._cl_keys import getKey, clearKey
 from calculate.lib.convertenv import convertEnv
 from calculate.lib.encrypt import encrypt
@@ -204,12 +204,12 @@ class commandServer(color_print):
             if not pwDialog:
                 pwDialog = [_("New password"),
                             _("Retype the new password")]
-            pwdA = getpass.getpass(pwDialog[0]+":")
-            pwdB = getpass.getpass(pwDialog[1]+":")
+            pwdA = getpass.getpass(pwDialog[0]+_(":"))
+            pwdB = getpass.getpass(pwDialog[1]+_(":"))
         if (optStdIn and options.has_key(optStdIn)) or\
             (optDialog and options.has_key(optDialog)):
             if not pwdA or not (pwdA == pwdB):
-                self.printERROR (_("ERROR") + ": " +\
+                self.printERROR (_("ERROR") + _(": ") +\
                 _("passwords do not match"))
                 return False
             userPwd = pwdA
@@ -252,11 +252,9 @@ class Client(commandServer, encrypt, Desktop):
         self.clVars.Delete("cl_remote_host", "local")
         self.clVars.Delete("cl_remote_pw", "local")
         self.clVars.Delete("os_remote_auth")
-        self.clVars.Delete("os_remote_client")
         self.clVars.Set("cl_remote_host", "", True)
         self.clVars.Set("cl_remote_pw", "", True)
         self.clVars.Set("os_remote_auth", "", True)
-        self.clVars.Set("os_remote_client", "", True)
         return True
 
     def mountSambaRes(self,host,userName,userPwd,res,rpath,uid=None,gid=None):
@@ -264,16 +262,20 @@ class Client(commandServer, encrypt, Desktop):
         Подключить samba ресурс
         """
         mountCmd = checkUtils('/bin/mount')
+        if cmpVersion(self.clVars.Get('cl_cifs_ver'),"2.05") < 0:
+            nomapposix=""
+        else:
+            nomapposix=",nomapposix"
         if not uid is None:
             # mount by uid
             p = process(mountCmd,"-t","cifs","-o",
-                "cache=loose,user=%s,uid=%d,gid=%d,noperm"%(userName,uid,gid),
+                "cache=loose,user=%s,uid=%d,gid=%d,noperm%s"%(userName,uid,gid,nomapposix),
                 "//%s/%s"%(host,res),rpath,
                 envdict={"PASSWD":userPwd},stderr=STDOUT)
             return p.success()
         else:
             p = process(mountCmd,"-t","cifs","-o",
-                "cache=loose,user=%s"%userName,
+                "cache=loose,user=%s%s"%(userName,nomapposix),
                 "//%s/%s"%(host,res),rpath,
                 envdict={"PASSWD":userPwd},stderr=STDOUT)
             return p.success()
@@ -329,12 +331,12 @@ class Client(commandServer, encrypt, Desktop):
 -rlpt -x -v -v -v %s/ %s/'%(excludePaths, userHome, remoteProfile)
         else:
             raise ClientError(
-                _("Method syncUser: option sync=%s is incorrect")%str(sync))
+                _("Method syncUser: wrong option sync=%s")%str(sync))
         if execStr:
             host = "<i>" + host +"</i>"
             if sync == "login":
                 rsync = RsyncProgressBar(\
-                        _("Receiving the file list from %s") % host,
+                        _("Fetching the file list from %s") % host,
                         _("Fetching the user profile from %s") % host,
                         execStr,self)
             else:
@@ -624,7 +626,7 @@ class Client(commandServer, encrypt, Desktop):
                 os.chown(userdir, uid, gid)
                 os.chmod(userdir,0700)
             except OSError:
-                raise ClientError(_("Error creating the directory")+". "+
+                raise ClientError(_("Failed to create the directory")+". "+
                                   _("Permission denied: '%s'")%userdir)
         return True
 
@@ -648,7 +650,7 @@ class Client(commandServer, encrypt, Desktop):
                 if not self.mountSleepRes(host, userName, userPwd,
                                       res, rpath,uid,gid):
                     raise ClientError(
-                        _("Failed to mount Samba resource [%s]")%res)
+                        _("Failed to mount the Samba volume [%s]")%res)
         else:
             return True
 
@@ -953,7 +955,7 @@ class Client(commandServer, encrypt, Desktop):
                    # \s*<название_службы>\s*|\s*<уроверь запуска>?\s*
                    p.readlines())))
         else:
-            raise ClientError(_("ERROR") + ": " + p.read())
+            raise ClientError(_("ERROR") + _(": ") + p.read())
 
     def delDaemonAutostart(self, daemon):
         """
@@ -966,7 +968,7 @@ class Client(commandServer, encrypt, Desktop):
             if p.success():
                 return True
             else:
-                self.printERROR(_("ERROR") + ": " + p.read())
+                self.printERROR(_("ERROR") + _(": ") + p.read())
                 self.printERROR(_("Failed to delete from the default runlevel"))
                 return False
         return True
@@ -982,7 +984,7 @@ class Client(commandServer, encrypt, Desktop):
         if p.success():
             return True
         else:
-            self.printERROR(_("ERROR") + ": " + p.read())
+            self.printERROR(_("ERROR") + _(": ") + p.read())
             self.printERROR(_("Failed to add to the default runlevel"))
             return False
 
@@ -1057,12 +1059,9 @@ class Client(commandServer, encrypt, Desktop):
                 yield remotePw
             if remotePw:
                 self.printERROR(_("Wrong password"))
-            # не запрашвать пароль при загрузке системы
-            if not path.exists('/proc/self/fd/0') or \
-                os.readlink('/proc/self/fd/0') != '/dev/console':
-                yield self.askPassword(\
-                        _("Domain password for the desktop"),False)
-                self.printERROR(_("Wrong password"))
+            yield self.askPassword(\
+                    _("Domain password for the desktop"),False)
+            self.printERROR(_("Wrong password"))
 
         pathRemote = "/var/calculate/remote"
         for pwdRemote in passwdQueue():
@@ -1079,7 +1078,6 @@ class Client(commandServer, encrypt, Desktop):
         # write domain to config
         self.clVars.Write("os_remote_auth", domain, True)
         # write current program version
-        self.clVars.Write("os_remote_client", currentVersion, True)
         self.clVars.Write("cl_remote_host", domain, True, "local")
         self.clVars.Write("cl_remote_pw", pwdRemote, True, "local")
         return True
@@ -1094,7 +1092,7 @@ class Client(commandServer, encrypt, Desktop):
         bindPw = self.getInfoService("unix", "bind_pw")
         # check info from server
         if not (servDn and unixDn and bindDn and bindPw):
-            raise ClientError(_("Info not found on the server") + ": " +\
+            raise ClientError(_("Info not found on the server") + _(": ") +
                 _("services DN or unix DN or bind DN or bind password"))
         self.clVars.Set("os_remote_auth", domain)
         return True
@@ -1119,16 +1117,14 @@ class Client(commandServer, encrypt, Desktop):
         # apply system templates
         self.applyTemplates(None,False)
         if hostAuth:
-            self.printSUCCESS(_("The workstation is configured for work "
+            self.printSUCCESS(_("The workstation was configured for work "
                               "in the domain"))
             currentVersion = self.clVars.Get("cl_ver")
-            self.clVars.Write("os_remote_client", currentVersion, True)
             self.clVars.Write("os_remote_auth", hostAuth, True)
         else:
-            self.printSUCCESS(_("The workstation is configured for work "
+            self.printSUCCESS(_("The workstation was configured for work "
                               "outside the domain"))
             self.clVars.Delete("os_remote_auth")
-            self.clVars.Delete("os_remote_client")
         return True
 
     def cDelLdapSysUsersAndSyncCache(self):
@@ -1181,21 +1177,21 @@ class Client(commandServer, encrypt, Desktop):
         domain = reduce(lambda x,y:x if x else y,domains,"")
         foundMountRemote = isMount(pathRemote)
         if foundMountRemote:
-            self.printWARNING(_("Samba resource [%s] mounted")%"remote")
+            self.printWARNING(_("Samba volume [%s] mounted")%"remote")
             return True
         else:
             if not (domain and pwdRemote):
-                self.printERROR(_("Variable not found")+\
-                        ": cl_remote_pw")
+                self.printERROR(_("Variable not found")+
+                                _(": ") + "cl_remote_pw")
                 return False
             if not os.path.exists(pathRemote):
                 os.makedirs(pathRemote)
             if not self.mountSambaRes(domain,"client",pwdRemote,
                                "remote",pathRemote):
                 self.printERROR(
-                    _("Failed to mount Samba resource [%s]")%"remote")
+                    _("Failed to mount the Samba volume [%s]")%"remote")
                 return False
-            self.printSUCCESS(_("Samba resource [%s] mounted") % "remote")
+            self.printSUCCESS(_("Samba volume [%s] mounted") % "remote")
             return True
 
     def clientPasswd(self,userLogin,uid,gid,homeDir,password,curPassword):
