@@ -62,7 +62,7 @@ class VariableClRemoteHostNew(Variable):
             if self.Get('cl_localhost_set') == 'off':
                 if self.Get('cl_remote_host') == '':
                     if not value:
-                        raise VariableError(_("Need to specify the domain"))
+                        raise VariableError(_("Please specify the domain"))
                     elif not isOpenPort(value,445):
                         raise VariableError(
                             _("The specified address is not available"))
@@ -157,7 +157,7 @@ class VariableClLocalhostSet(Variable):
     untrusted = True
 
     def init(self):
-        self.label = _("Computer role")
+        self.label = _("Workstation role")
         self.help = _("remove the domain connection settings")
 
     def choice(self):
@@ -167,9 +167,9 @@ class VariableClLocalhostSet(Variable):
     def check(self,value):
         if self.Get('cl_client_mount_set') == 'off':
             if self.Get('cl_remote_host') == '' and value == "on":
-                raise VariableError(_("The computer is not in the domain"))
+                raise VariableError(_("The workstation is not in the domain"))
             if self.Get('cl_remote_host') != '' and value == "off":
-                raise VariableError(_("The computer is already in the domain %s")
+                raise VariableError(_("The workstation is already in the domain %s")
                                 %self.Get('cl_remote_host') + "\n" + 
                                 _("Before joining the domain, "
                                 "you need to remove it from the previous domain"))
@@ -271,10 +271,10 @@ class VariableClClientLogin(VariableUrLogin):
         if not value in self.choice() and self.Get('cl_action') == 'logout':
             raise VariableError(_("X session users not found"))
         if value == "":
-            raise VariableError(_("Need to specify user"))
+            raise VariableError(_("Please specify the user"))
         if value == "root" and self.Get('cl_action') == 'passwd':
             raise VariableError(\
-                _("The action can be executed by a non-root user only"))
+                _("This action can be executed by a non-root user only"))
         try:
             pwd.getpwnam(value).pw_gid
         except:
@@ -293,17 +293,16 @@ class VariableClClientRelevanceSet(ReadonlyVariable):
     type = "bool"
 
     def get(self):
+        # если происходят действия ввода или вывода из домена
+        if (self.Get('cl_action') in ("domain","undomain") and
+            self.Get('cl_client_mount_set') == 'off'):
+            return "off"
         # если изменился домен
         if self.Get('cl_remote_host') != self.Get("os_remote_auth"):
             return "off"
         if (self.Get('cl_remote_host') and
             not isMount(self.Get('cl_client_remote_path'))):
             return "off"
-        currentVersion = self.Get("cl_ver")
-        # версия программы, который были наложены шаблоны
-        previousVersion = self.Get("os_remote_client")
-        if cmpVersion(currentVersion,previousVersion):
-            return "off"
         return "on"
 
 class VariableClClientRemotePath(Variable):
